Learn R Programming

L1pack (version 0.62-4)

vcov.lad: Calculate variance-covariance matrix from lad models

Description

Returns the variance-covariance matrix of the main parameters of a fitted model for lad objects. The “main” parameters of model correspond to those returned by coef, and typically do not contain the nuisance scale parameter.

Usage

# S3 method for lad
vcov(object, level = 0.95, ...)

Value

A matrix of the estimated covariances between the parameter estimates in the linear regression model. This should have row and column names corresponding to the parameter names given by the coef method. The nuisance parameter required for the evaluation of the asympotic covariance matrix is estimated using the method proposed by McKean and Schrader (1987).

Arguments

object

an object representing a fitted model.

level

the confidence level required for estimating the nuisance parameter involved in the asymptotic covariance matrix.

...

additional arguments for method functions.

References

Gonin, R., Money, A.H. (1989). Nonlinear Lp-norm Estimation. Marcel Dekker, New York.

McKean, J.W., Schrader, R.M. (1987). Least absolute errors analysis of variance. In: Y. Dodge (Ed.), Statistical data analysis - Based on the L1-norm and related methods. North Holland, Amsterdam, pp. 297-305.